@@ -3,17 +3,17 @@
 
 // Version defines
 #define WT_SERIES 4
-#define WT_MAJOR  10
-#define WT_MINOR  4
+#define WT_MAJOR  12
+#define WT_MINOR  0
 
 /*! \brief A constant that encodes the library version of %Wt
  *
  * You may use this constant to check for the version of %Wt at build-time.
  */
 #define WT_VERSION (((WT_SERIES & 0xff) << 24) | ((WT_MAJOR & 0xff) << 16) | ((WT_MINOR & 0xff) << 8))
-#define WT_VERSION_STR "4.10.4"
-#define WT_CLASS       "Wt4_10_4"
-#define WT_INCLUDED_VERSION Wt_4_10_4
+#define WT_VERSION_STR "4.12.0"
+#define WT_CLASS       "Wt4_12_0"
+#define WT_INCLUDED_VERSION Wt_4_12_0
 
 #define RUNDIR "/var/run/wt"
 #define WT_CONFIG_XML "/etc/wt/wt_config.xml"
@@ -41,6 +41,10 @@
 /* #undef WT_ANY_IS_EXPERIMENTAL_ANY */
 /* #undef WT_ANY_IS_STD_ANY */
 
+#define WT_FILESYSTEM_IMPL_BOOST
+/* #undef WT_FILESYSTEM_IMPL_STD */
+/* #undef WT_FILESYSTEM_IMPL_STD_CLOCK_17 */
+
 #define WT_DATE_TZ_USE_DATE
 /* #undef WT_DATE_TZ_USE_STD */
 
