@@ -173,7 +173,7 @@ public:
    * \sa offset(Side) const
    */
   virtual void setOffsets(const WLength& offset,
-			  WFlags<Side> sides = AllSides) = 0;
+                          WFlags<Side> sides = AllSides) = 0;
 
 #ifdef WT_TARGET_JAVA
   /*! \brief Sets CSS offsets for a non-statically positioned widget.
@@ -201,7 +201,7 @@ public:
    * widget following CSS rules.
    *
    * When the widget is not managed by a layout manager, the automatic
-   * (natural) size of a widget depends on whether they widget is a
+   * (natural) size of a widget depends on whether the widget is a
    * <i>block</i> or <i>inline</i> widget:
    * - a <i>block</i> widget takes by default the width of the parent, and the height
    *   that it needs based on its contents
@@ -370,11 +370,24 @@ public:
    * case there is not enough room to the right). It is aligned so
    * that the top edges align (or the bottom edges if there is not
    * enough room below).
+   * 
+   * \p adjustOrientations allows to specify the axes on which the
+   * widget can adjust it's position if there is not enough room next
+   * to the other widget, breaking the previous rules if necessary. For
+   * example, if Orientation::Vertical flag of \p adjustOrientations is
+   * set, and part of the widget would be cut off by the top of the
+   * window, the widget would be move downward until the top of the
+   * widget is fully visible (or the widget reaches the bottom of the
+   * window). In that case, the widget would not be aligned with the
+   * other widget, in case \p orientation = Wt::Orientation::Horizontal,
+   * or would be displayed over the other widget, in case \p orientation
+   * = Wt::Orientation::Vertical.
    *
    * \note This only works if JavaScript is available.
    */
   virtual void positionAt(const WWidget *widget,
-			  Orientation orientation = Orientation::Vertical);
+                          Orientation orientation = Orientation::Vertical,
+                          WFlags<Orientation> adjustOrientations = AllOrientations);
 
   /*! \brief Sets the CSS line height for contained text.
    */
@@ -409,7 +422,7 @@ public:
    * This pushes the widget down until it is not surrounded by floats
    * at the \p sides (which may be a combination of Wt::Side::Left and
    * Wt::Side::Right).
-   * 
+   *
    * This applies to CSS-based layout.
    *
    * \sa setFloatSide()
@@ -435,7 +448,7 @@ public:
    * \sa margin()
    */
   virtual void setMargin(const WLength& margin,
-			 WFlags<Side> sides = AllSides) = 0;
+                         WFlags<Side> sides = AllSides) = 0;
 
 #ifdef WT_TARGET_JAVA
   /*! \brief Sets CSS margins around the widget.
@@ -445,7 +458,7 @@ public:
    * \sa setMargin(const WLength&, WFlags<Side>)
    */
   virtual void setMargin(int pixels,
-			 WFlags<Side> sides = AllSides);
+                         WFlags<Side> sides = AllSides);
 #endif // WT_TARGET_JAVA
 
   /*! \brief Returns a CSS margin set.
@@ -489,7 +502,7 @@ public:
    * \endif
    */
   virtual void setHidden(bool hidden,
-			 const WAnimation& animation = WAnimation()) = 0;
+                         const WAnimation& animation = WAnimation()) = 0;
 
   /*! \brief Returns whether the widget is set hidden.
    *
@@ -517,11 +530,19 @@ public:
 
   /*! \brief Sets whether the widget is disabled.
    *
-   * Enables or disables the widget (including all its descendant
-   * widgets). setDisabled(false) will enable this widget and all
-   * descendant widgets that are not disabled. A widget is only
-   * enabled if it and all its ancestors in the widget tree are
-   * disabled.
+   * The widget can be set to being disabled, or enabled. This state
+   * will also be propagated to all its descendants. Those descendants
+   * will only be "visually" made disabled, their actual isDisabled()
+   * state will remain unaltered. All descendants will be assigned the
+   * disabled styleclass, which is dependent on the used Theme.
+   *
+   * The isDisabled() check will thus only return \p true in case
+   * setDisabled(true) has been called on the widget before. If the
+   * anscestor of a widget has been marked setDisabled(true), the
+   * widget's isDisabled() state will remain \p false.
+   *
+   * To check if a widget has been passively disabled, by one of its
+   * anscestors, use isEnabled().
    *
    * Typically, a disabled form widget will not allow changing the
    * value, and disabled widgets will not react to mouse click events.
@@ -538,9 +559,9 @@ public:
 
   /*! \brief Returns whether the widget is set disabled.
    *
-   * A widget that is not set disabled may still be disabled when one
-   * of its ancestor widgets is set disabled. Use isEnabled() to find
-   * out whether a widget is enabled.
+   * This method will return \p true if, and only if, it has been marked
+   * setDisabled(true) explicitly. It can still inherit the disabled
+   * state from one of its anscestors.
    *
    * \sa setDisabled(), isEnabled()
    */
@@ -630,7 +651,7 @@ public:
    * flexible way to provide many widgets the same markup.
    *
    * Setting an empty string removes the style class(es).
-   * 
+   *
    * \sa WApplication::styleSheet()
    */
   virtual void setStyleClass(const WT_USTRING& styleClass) = 0;
@@ -655,7 +676,7 @@ public:
    * are all not yet present on the element.
    */
   virtual void addStyleClass(const WT_USTRING& styleClass,
-			     bool force = false) = 0;
+                             bool force = false) = 0;
 
   void addStyleClass(const char *styleClass, bool force = false);
 
@@ -669,14 +690,14 @@ public:
    * The \p styleClass should be a single class
    */
   virtual void removeStyleClass(const WT_USTRING& styleClass,
-				bool force = false) = 0;
+                                bool force = false) = 0;
 
   void removeStyleClass(const char *styleClass, bool force = false);
 
   /*! \brief Toggles a CSS style class.
    */
   virtual void toggleStyleClass(const WT_USTRING& styleClass, bool add,
-				bool force = false);
+                                bool force = false);
 
   void toggleStyleClass(const char *styleClass, bool add, bool force = false);
 
@@ -692,7 +713,7 @@ public:
    * This applies to CSS-based layout.
    */
   virtual void setVerticalAlignment(AlignmentFlag alignment,
-				    const WLength& length = WLength::Auto) = 0;
+                                    const WLength& length = WLength::Auto) = 0;
 
   /*! \brief Returns the vertical alignment.
    *
@@ -722,7 +743,7 @@ public:
    * \sa setDeferredTooltip()
    */
   virtual void setToolTip(const WString& text,
-			  TextFormat textFormat = TextFormat::Plain) = 0;
+                          TextFormat textFormat = TextFormat::Plain) = 0;
 
   /*! \brief Returns the tooltip.
    */
@@ -777,7 +798,7 @@ public:
    * \sa JSlot, doJavaScript()
    */
   virtual void setAttributeValue(const std::string& name,
-				 const WT_USTRING& value) = 0;
+                                 const WT_USTRING& value) = 0;
 
   /*! \brief Returns an attribute value.
    *
@@ -799,7 +820,7 @@ public:
    * instead of setting the CSS width and height properties.
    */
   virtual void setJavaScriptMember(const std::string& name,
-				   const std::string& value) = 0;
+                                   const std::string& value) = 0;
 
   /*! \brief Returns the value of a JavaScript member.
    *
@@ -814,7 +835,7 @@ public:
    * \sa setJavaScriptMember()
    */
   virtual void callJavaScriptMember(const std::string& name,
-				    const std::string& args) = 0;
+                                    const std::string& args) = 0;
 
   /*! \brief Short hand for WString::tr()
    *
@@ -925,7 +946,7 @@ public:
    * \sa dropEvent(), WInteractWidget::setDraggable(), stopAcceptDrops()
    */
   virtual void acceptDrops(const std::string& mimeType,
-			   const WT_USTRING& hoverStyleClass = WT_USTRING());
+                           const WT_USTRING& hoverStyleClass = WT_USTRING());
 
   /*! \brief Indicates that a mime type is no longer accepted for dropping.
    *
@@ -1092,7 +1113,7 @@ public:
    *       may not be correctly emitted, because then Wt can't properly keep track of
    *       the state that the widget is in on the client side.
    *       This feature is not intended to be toggled on and off, but rather enabled
-   * 	   once and disabled once after that.
+   *       once and disabled once after that.
    */
   virtual void setScrollVisibilityEnabled(bool enabled) = 0;
 
@@ -1131,15 +1152,15 @@ public:
    *
    * By default all widgets are styled according to the chosen theme.
    * Disabling the theme style could be useful to completely customize the style of the widget
-   * outside of the theme. 
+   * outside of the theme.
    *
-   * \note This should be changed after the construction but before the rendering 
+   * \note This should be changed after the construction but before the rendering
    * of the widget.
    */
   virtual void setThemeStyleEnabled(bool enabled) = 0;
 
   /*!
-   * \brief Returns whether this widget is currently styled by 
+   * \brief Returns whether this widget is currently styled by
    * the chosen theme.
    *
    * isThemeEnabled() is initially true.
@@ -1291,9 +1312,9 @@ protected:
   virtual void propagateSetVisible(bool visible) = 0;
 
   void getDrop(const std::string sourceId, const std::string mimeType,
-	       WMouseEvent event);
+               WMouseEvent event);
   void getDropTouch(const std::string sourceId, const std::string mimeType,
-	       WTouchEvent event);
+               WTouchEvent event);
 
   virtual void setHideWithOffsets(bool how = true) = 0;
 
@@ -1341,15 +1362,15 @@ protected:
   bool needRerender() const { return flags_.test(BIT_NEED_RERENDER); }
 
   virtual void getSDomChanges(std::vector<DomElement *>& result,
-			      WApplication *app) = 0;
+                              WApplication *app) = 0;
   virtual bool needsToBeRendered() const = 0;
   bool isInLayout() const;
 
   virtual bool hasParent() const;
 
   WCssTextRule *addCssRule(const std::string& selector,
-			   const std::string& declarations,
-			   const std::string& ruleName = std::string());
+                           const std::string& declarations,
+                           const std::string& ruleName = std::string());
 
   bool isGlobalWidget() const;
 
