@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -9,7 +9,7 @@
 
 #include <Wt/WTreeTable.h>
 
-#include <boost/filesystem/path.hpp>
+#include <Wt/cpp17/filesystem.hpp>
 
 /**
  * \defgroup fileexplorer File Explorer example
@@ -23,7 +23,7 @@
  * and modification date.
  *
  * The table use FileTreeTableNode objects to display the actual content
- * of the table. 
+ * of the table.
  *
  * The tree table uses the LazyLoading strategy of WTreeNode to dynamically
  * load contents for the tree.
@@ -37,7 +37,7 @@ public:
    *
    * Create a new FileTreeTable to browse the given path.
    */
-  FileTreeTable(const boost::filesystem::path& path);
+  FileTreeTable(const Wt::cpp17::filesystem::path& path);
 };
 
 /*@}*/
